@@ -4,7 +4,6 @@ OC.L10N.register(
     "Mail" : "البريد",
     "Loading accounts" : "تجهيز الحسابات",
     "Error while loading the accounts." : "حدث خطأ خلال تحميل الحسابات.",
-    "Error while loading the selected account." : "حدث خطأ خلال تحميل الحساب المُختار.",
     "Can not load this folder." : "يتعذر تحميل هذا المجلد.",
     "Searching for {query}" : "بحث عن {query}",
     "Error while deleting message." : "حدث خطأ خلال حذف الرسالة.",
@@ -116,7 +115,6 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "تح حجب هذه الصورة لحماية خصوصيتك",
     "Show images from this sender" : "أظهر الصور من هذا المُرسل",
     "Forward" : "مرر",
-    "No messages in this folder!" : "هذا المجلد خالٍ مِن الرسائل !",
     "Upload attachment" : "رفع المرفقات",
     "Add attachment from Files" : "إضافة مرفقات مِن الملفات",
     "Import into calendar" : "إستيراد من التقويم",
