@@ -2,8 +2,9 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "Поща",
+    "Loading accounts" : "Зареждане на акаунти",
     "Error while loading the accounts." : "Грешка при зареждането на профилите.",
-    "Error while loading the selected account." : "Грешка при зареждането на избрания профил.",
+    "Can not load this folder." : "Тази папка не може да се зареди.",
     "Searching for {query}" : "Търсене на {query}",
     "Error while deleting message." : "Грешка при изтриването на съобщение.",
     "Forwarded message" : "Препратено съобщение",
@@ -12,14 +13,18 @@ OC.L10N.register(
     "Attachment saved to Files." : "Прикачения файл е запазен във Файлове.",
     "Error while saving attachments to Files." : "Грешка при запазване на прикачените файлове във Файлове.",
     "Error while saving attachment to Files." : "Грешка при запазване на прикаченият файл във Файлове.",
+    "Could not move message." : "Съобщението не може да бъде преместено",
     "Invalid account" : "Невалиден профил",
     "Invalid folder" : "Невалидна папка",
     "Unknown error" : "Неизвестна грешка",
     "All inboxes" : "Всички",
     "you" : "ти",
+    "Send message to {email}" : "Изпрати съобщение до {email}",
     "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag} не може да бъде зареден",
     "There was a problem loading {tag}{name}{endtag}" : "Проблем при зареждане на {tag}{name}{endtag}",
+    "Could not load the message" : "Съобщението не може да бъде заредено",
     "Save" : "Запазване",
+    "Saved" : "Запазено",
     "Show all folders" : "Покажи всички папки",
     "Error while deleting account." : "Грешка при изтриването на профил.",
     "Choose a file to add as attachment" : "Избери файл за прикачване",
@@ -27,9 +32,12 @@ OC.L10N.register(
     "Send" : "Изпрати",
     "Sending …" : "Изпращане...",
     "Message sent!" : "Съобщението е изпратено!",
+    "Server error" : "Сървърна грешка",
     "An unknown error occurred" : "Възникна неизвестна грешка",
+    "No writable calendars found" : "Не са открити календари за запис",
     "& others" : "и други",
     "Error while loading messages." : "Грешка при зареждане на съобщенията.",
+    "Setting up your account" : "Настройване на профила ви",
     "Inbox" : "Входяши",
     "Sent" : "Изпратени",
     "Drafts" : "Чернови",
