@@ -4,7 +4,6 @@ OC.L10N.register(
     "Mail" : "Correu electrónic",
     "Loading accounts" : "S'està carregant",
     "Error while loading the accounts." : "Error al carregar els comptes.",
-    "Error while loading the selected account." : "Error al carregar el compte sel·leccionat.",
     "Can not load this folder." : "No s'ha pogut carregar aquesta carpeta.",
     "Searching for {query}" : "Buscant per {query}",
     "Error while deleting message." : "Error en esborrar el missatge.",
@@ -59,7 +58,7 @@ OC.L10N.register(
     "Creating account failed: " : "La creació del compte ha fallat:",
     "Delete permanently" : "Esborra permanentment",
     "Error loading message" : "Error al carregar el missatge",
-    "Settings" : "Paràmetres",
+    "Settings" : "Configuració",
     "Forwarding to %s" : "Reenviant a %s",
     "Click here if you are not automatically redirected within the next few seconds." : "Prem aquí si no se't redirigeix automàticament en pocs segons.",
     "Redirect" : "Redireccionar",
@@ -112,7 +111,6 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "S'han bloquejat les imatges per protegir la teva privacitat.",
     "Show images from this sender" : "Mostra imatges d'aquest remitent",
     "Forward" : "Respondre",
-    "No messages in this folder!" : "No hi ha missatges en aquesta carpeta!",
     "Import into calendar" : "Importar al calendari",
     "Download attachment" : "Descarrega l'adjunt",
     "Save to Files" : "Desa els fitxers"
