@@ -4,7 +4,6 @@ OC.L10N.register(
     "Mail" : "Mail",
     "Loading accounts" : "Indlæser kontoerne...",
     "Error while loading the accounts." : "Fejl under indlæsning af konti.",
-    "Error while loading the selected account." : "Der opstod en fejl under læsningen af den valgte konto.",
     "Can not load this folder." : "Kan ikke indlæse denne mappe.",
     "Searching for {query}" : "Leder efter {query}",
     "Error while deleting message." : "Fejl under sletning af besked.",
@@ -113,7 +112,6 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Dette billede er blevet blokeret for at beskytte din privat liv",
     "Show images from this sender" : "Vis billeder fra denne afsender",
     "Forward" : "Videre send",
-    "No messages in this folder!" : "Ingen beskeder i denne mappe!",
     "Upload attachment" : "Upload vedhæftning",
     "Add attachment from Files" : "Vedhæft fra filer",
     "Import into calendar" : "Importere til kalender",
