@@ -4,7 +4,6 @@ OC.L10N.register(
     "Mail" : "Αλληλογραφία",
     "Loading accounts" : "Γίνεται φόρτωση λογαριασμών",
     "Error while loading the accounts." : "Σφάλμα κατά τη φόρτωση των λογαριασμών.",
-    "Error while loading the selected account." : "Σφάλμα κατά τη φόρτωση του επιλεγμένου λογαριασμού.",
     "Can not load this folder." : "Αδυναμία φόρτωσης αυτού του φακέλου.",
     "Searching for {query}" : "Αναζήτηση για {query}",
     "Error while deleting message." : "Σφάλμα κατά τη διαγραφή του μηνύματος.",
@@ -20,13 +19,16 @@ OC.L10N.register(
     "Invalid folder" : "Μη έγκυρος φάκελος",
     "Error while creating the account: " : "Σφάλμα κατά τη δημιουργία του λογαριασμού:",
     "Unknown error" : "Άγνωστο σφάλμα",
+    "Error while updating the account: " : "Σφάλμα κατά την ενημέρωση του λογαριασμού:",
     "All inboxes" : "Όλα τα εισερχόμενα",
     "you" : "εσείς",
     "Send message to {email}" : "Αποστολή μηνύματος σε {email}",
     "Could not load {tag}{name}{endtag}" : "Αδυναμία φόρτωσης {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Παρουσιάστηκε πρόβλημα φόρτωσης {tag}{name}{endtag}",
     "{from}\n{subject}" : "{from}\n{subject}",
+    "Nextcloud Mail" : "Αλληλογραφία Nextcloud",
     "Save" : "Αποθήκευση",
+    "Saved" : "Αποθηκεύτηκε",
     "Show all folders" : "Εμφάνιση όλων των φακέλων",
     "Collapse folders" : "Σύμπτυξη φακέλων",
     "Error while deleting account." : "Σφάλμα κατά τη διαγραφή λογαριασμού.",
@@ -53,6 +55,7 @@ OC.L10N.register(
     "All" : "Όλα",
     "Favorites" : "Αγαπημένα",
     "Auto detect failed. Please use manual mode." : "Η αυτόματη ανίχνευση απέτυχε. Παρακαλούμε χρησιμοποιήστε τη χειροκίνητη λειτουργία.",
+    "Updating account failed: " : "Αποτυχία ενημέρωσης λογαριασμού:",
     "Creating account failed: " : "Αποτυχία δημιουργίας λογαριασμού:",
     "Delete permanently" : "Μόνιμη διαγραφή",
     "Error loading message" : "Σφάλμα φόρτωσης μηνύματος",
@@ -70,8 +73,10 @@ OC.L10N.register(
     "Aliases" : "Ψευδώνυμα",
     "Mail address" : "Διεύθυνση αλληλογραφίας",
     "Display Name" : "Εμφανιζόμενο όνομα",
+    "Account" : "Λογαριασμός",
     "Keyboard shortcuts" : "Συντομεύσεις πληκτρολογίου",
     "Speed up your Mail experience with these quick shortcuts." : "Βελτιώστε την ταχύτητά σας στην εμπειρία χρήσης στο πρόγραμμα Αλληλογραφίας με αυτές τις συντομεύσεις.",
+    "Compose new message" : "Σύνταξη νέου μηνύματος",
     "Newer message" : "Νεότερο μήνυμα",
     "Older message" : "Παλαιότερο μήνυμα",
     "Toggle star" : "Εναλλαγή αστεριού",
