@@ -4,7 +4,6 @@ OC.L10N.register(
     "Mail" : "Correo",
     "Loading accounts" : "Cargando cuentas",
     "Error while loading the accounts." : "Se presentó un error al cargar las cuentas.",
-    "Error while loading the selected account." : "Se presentó un error al cargar la cuenta seleccionada. ",
     "Can not load this folder." : "No se puede cargar esta carpeta.",
     "Searching for {query}" : "Buscando a {query}",
     "Error while deleting message." : "Se presentó un error al borrar el mensaje.",
@@ -65,6 +64,8 @@ OC.L10N.register(
     "Updating account failed: " : "Se presentó una falla al actualizar la cuenta",
     "Creating account failed: " : "Se presentó una falla al crear la cuenta:",
     "Delete permanently" : "Borrar permanentemente",
+    "IMAP web client" : "Cliente web IMAP",
+    "Easy to use email client which connects to your mail server via IMAP and SMTP." : "Cliente de correo electrónico fácil de usar que se conecta con tu servidor de correo vía IMAP y SMTP.",
     "Error loading message" : "Se presentó un error al cargar el mensaje",
     "Settings" : "Configuraciones ",
     "Forwarding to %s" : "Reenviando a %s",
@@ -122,7 +123,7 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
     "Show images from this sender" : "Mostrar imagenes de este remitente",
     "Forward" : "Reenviar",
-    "No messages in this folder!" : "¡No hay mensajes en esta carpeta!",
+    "No messages in this folder" : "No hay mensajes en esta carpeta",
     "Upload attachment" : "Cargar adjunto",
     "Add attachment from Files" : "Agregar adjunto desd Archivos",
     "Import into calendar" : "Importar al calendario",
