@@ -65,6 +65,7 @@ OC.L10N.register(
     "Creating account failed: " : "Tilin luominen epäonnistui:",
     "Delete permanently" : "Poista pysyvästi",
     "IMAP web client" : "IMAP-verkkoasiakas",
+    "Easy to use email client which connects to your mail server via IMAP and SMTP." : "Helppokäyttöinen sähköpostisovellus, joka yhdistää palvelimiin IMAP- ja SMTP-protokollia käyttäen.",
     "Error loading message" : "Virhe viestiä ladatessa",
     "Settings" : "Asetukset",
     "Forwarding to %s" : "Välitä viesti %s",
@@ -117,6 +118,7 @@ OC.L10N.register(
     "Subject" : "Aihe",
     "Save all to Files" : "Tallenna kaikki tiedostoihin",
     "Add mail account" : "Lisää sähköpostitili",
+    "Use Gravatar and favicon avatars" : "Käytä Gravatar- ja favicon-avatareja",
     "No search results for" : "Ei tuloksia haulle",
     "The images have been blocked to protect your privacy." : "Kuvat estettiin yksityisyytesi suojelemiseksi.",
     "Show images from this sender" : "Näytä kuvat tältä lähettäjältä",
