@@ -4,7 +4,6 @@ OC.L10N.register(
     "Mail" : "Póstur",
     "Loading accounts" : "Hleð inn notendaaðgöngum",
     "Error while loading the accounts." : "Gat ekki lesið inn notandaaðganga..",
-    "Error while loading the selected account." : "Villa við að lesa inn valinn notandaaðgang.",
     "Can not load this folder." : "Gat ekki að hlaðið inn möppunni.",
     "Searching for {query}" : "Leita að {query}",
     "Error while deleting message." : "Villa kom upp við að eyða skilaboðum.",
@@ -122,7 +121,7 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Lokað hefur verið á myndir til að vernda einkalíf þitt.",
     "Show images from this sender" : "Birta myndir frá þessum sendanda",
     "Forward" : "Áframsenda",
-    "No messages in this folder!" : "Engin skilaboð í þessari möppu!",
+    "No messages in this folder" : "Engin skilaboð í þessari möppu",
     "Upload attachment" : "Senda inn viðhengi",
     "Add attachment from Files" : "Bæta við viðhengi úr skrám",
     "Import into calendar" : "Flytja inn dagatal",
