@@ -4,7 +4,6 @@ OC.L10N.register(
     "Mail" : "E-post",
     "Loading accounts" : "Laster kontoer",
     "Error while loading the accounts." : "Feil ved innlasting av kontoene.",
-    "Error while loading the selected account." : "Feil ved lasting av den valgte kontoen.",
     "Can not load this folder." : "Kan ikke laste denne mappen.",
     "Searching for {query}" : "Søker etter {query}",
     "Error while deleting message." : "Feil ved sletting av melding.",
@@ -122,7 +121,7 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Bildene har blitt blokkert for å beskytte privatlivet.",
     "Show images from this sender" : "Vis bilder fra denne avsenderen",
     "Forward" : "Videresend",
-    "No messages in this folder!" : "Det er ingen meldinger i denne mappen!",
+    "No messages in this folder" : "Ingen meldinger i denne mappen",
     "Upload attachment" : "Last opp vedlegg",
     "Add attachment from Files" : "Legg til vedlegg fra Filer",
     "Import into calendar" : "Importer til kalender",
