@@ -4,7 +4,6 @@ OC.L10N.register(
     "Mail" : "E-mail",
     "Loading accounts" : "Accounts laden",
     "Error while loading the accounts." : "Fout tijdens het laden van de accounts.",
-    "Error while loading the selected account." : "Fout tijdens het laden van het gekozen account.",
     "Can not load this folder." : "Kan deze map niet laden.",
     "Searching for {query}" : "Zoeken naar {query}",
     "Error while deleting message." : "Fout bij verwijderen bericht.",
@@ -113,6 +112,7 @@ OC.L10N.register(
     "to" : "aan",
     "cc" : "cc",
     "bcc" : "bcc",
+    "Note that the mail came from a noreply address so your reply will probably not be read." : "Let op: het e-mailbericht kwam van een niet-antwoord adres, waardoor je antwoord vermoedelijk niet zal worden gelezen.",
     "Subject" : "Onderwerp",
     "Save all to Files" : "Sla alles op in Bestanden",
     "Add mail account" : "Voeg e-mail account toe",
@@ -121,7 +121,7 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "De afbeeldingen zijn geblokkeerd om je privacy te beschermen",
     "Show images from this sender" : "Laat afbeeldingen zien van deze afzender",
     "Forward" : "Doorsturen",
-    "No messages in this folder!" : "Geen berichten in deze map!",
+    "No messages in this folder" : "Geen berichten in deze map",
     "Upload attachment" : "Bijlage uploaden",
     "Add attachment from Files" : "Bijlage toevoegen vanuit Bestanden",
     "Import into calendar" : "Toevoegen aan agenda",
