@@ -1,7 +1,7 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "Email",
+    "Mail" : "E-mail",
     "Loading accounts" : "Carregando contas",
     "Error while loading the accounts." : "Erro ao carregar as contas.",
     "Can not load this folder." : "Não foi possível carregar esta pasta.",
@@ -30,7 +30,7 @@ OC.L10N.register(
     "Could not load the message" : "Não foi possível carregar a mensagem",
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nova mensagem \nde {from}","%n novas mensagens \nde {from}"],
-    "Nextcloud Mail" : "Email Nextcloud",
+    "Nextcloud Mail" : "E-mail Nextcloud",
     "Save" : "Salvar",
     "Saved" : "Salvo",
     "Show all folders" : "Mostrar todas as pastas",
@@ -65,25 +65,25 @@ OC.L10N.register(
     "Creating account failed: " : "A criação de contas falhou:",
     "Delete permanently" : "Excluir permanentemente",
     "IMAP web client" : "Cliente web IMAP",
-    "Easy to use email client which connects to your mail server via IMAP and SMTP." : "Cliente de email fácil de usar que se conecta ao seu servidor de e-mail via IMAP e SMTP.",
+    "Easy to use email client which connects to your mail server via IMAP and SMTP." : "Cliente de e-mail fácil de usar que se conecta ao seu servidor de e-mail via IMAP e SMTP.",
     "Error loading message" : "Erro carregando mensagem",
     "Settings" : "Configurações",
     "Forwarding to %s" : "Encaminhando para %s",
     "Click here if you are not automatically redirected within the next few seconds." : "Clique aqui se você não for redirecionado automaticamente em alguns segundos",
     "Redirect" : "Redirecionar",
     "The link leads to %s" : "O link leva a %s",
-    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Se você não quiser visitar essa página, você pode retornar ao <a href=\"%s\">email</a>.",
+    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Se você não quiser visitar essa página, você pode retornar ao <a href=\"%s\">e-mail</a>.",
     "Continue to %s" : "Continue para %s",
     "Delete account" : "Excluir conta",
     "Try again" : "Tentar novamente",
     "New message" : "Nova mensagem",
     "Account Settings" : "Configurações de conta",
     "Aliases" : "Apelido",
-    "Mail address" : "Endereço de email",
+    "Mail address" : "Endereço de e-mail",
     "Display Name" : "Nome",
     "Account" : "Conta",
     "Keyboard shortcuts" : "Atalhos de teclado",
-    "Speed up your Mail experience with these quick shortcuts." : "Acelere o uso de seu email com estes atalhos rápidos.",
+    "Speed up your Mail experience with these quick shortcuts." : "Acelere o uso de seu e-mail com estes atalhos rápidos.",
     "Compose new message" : "Redigir nova mensagem",
     "Newer message" : "Mensagem mais recente",
     "Older message" : "Mensagem mais antiga",
@@ -92,9 +92,9 @@ OC.L10N.register(
     "Delete" : "Excluir",
     "Search" : "Pesquisar",
     "Refresh" : "Atualizar",
-    "Connect your mail account" : "Conectar sua conta de email",
+    "Connect your mail account" : "Conectar sua conta de e-mail",
     "Name" : "Nome",
-    "Mail Address" : "Endereço de email",
+    "Mail Address" : "Endereço de e-mail",
     "Password" : "Senha",
     "Manual configuration" : "Configuração manual",
     "IMAP Host" : "Host IMAP",
@@ -114,10 +114,10 @@ OC.L10N.register(
     "to" : "para",
     "cc" : "cc",
     "bcc" : "cco",
-    "Note that the mail came from a noreply address so your reply will probably not be read." : "Observe que o email veio de um endereço no-reply então sua resposta provavelmente não será lida.",
+    "Note that the mail came from a noreply address so your reply will probably not be read." : "Observe que o e-mail veio de um endereço no-reply então sua resposta provavelmente não será lida.",
     "Subject" : "Assunto",
     "Save all to Files" : "Salvar tudo para Arquivos",
-    "Add mail account" : "Adicionar conta de email",
+    "Add mail account" : "Adicionar conta de e-mail",
     "Use Gravatar and favicon avatars" : "Usar Gravatar e avatares para favicon",
     "No search results for" : "Nenhum resultado de busca para",
     "The images have been blocked to protect your privacy." : "As imagens foram bloqueadas para proteger sua privacidade",
