@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Mail" : "Posta",
     "Error while loading the accounts." : "Gabim gjatë ngarkimit të llogarive.",
-    "Error while loading the selected account." : "Gabim gjatë ngarkimit të llogarisë së përzgjedhur.",
     "Can not load this folder." : "Nuk mund të ngarkohet kjo dosje.",
     "Searching for {query}" : "Duke kërkuar për {query}",
     "Error while deleting message." : "Gabim gjatë fshirjes së mesazhit.",
@@ -108,7 +107,6 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Imazhet janë bllokuar për të mbrojtur privatësinë tuaj.",
     "Show images from this sender" : "Trego imazhet nga ky dërgues",
     "Forward" : "Ridrejto",
-    "No messages in this folder!" : "Asnjë mesazh në këtë dosje!",
     "Upload attachment" : "Ngarko bashkëngjitje",
     "Import into calendar" : "Importo në kalendar",
     "Download attachment" : "Shkarko bashkëlidhjen",
